pyxmpp.jabber.vcard.VCardKey

Package pyxmpp :: Package jabber :: Module vcard :: Class VCardKey |
[hide private]

# Class VCardKey

source code

    VCardField --+
                 |
                VCardKey

Key vCard field.

Instance Methods | [hide private]
__init__(self, name, value, rfc2425parameters=None) Initialize a VCardKey object. | source code
`str` |
rfc2426(self) RFC2426-encode the field content. | source code
`libxml2.xmlNode` |
as_xml(self, parent) Create vcard-tmp XML representation of the field. | source code
Inherited from `VCardField`: `__repr__`

Instance Variables | [hide private]
`str` | cred key data.
`unicode` | type key type.
Inherited from `VCardField`: `name`

Method Details | [hide private]

### __init__(self, name, value, rfc2425parameters=None) (Constructor) | source code
Initialize a VCardKey object. Parameters: `name` (`str`) - field name `value` (`str` or `libxml2.xmlNode`) - field value as string or an XML node `rfc2425parameters` (`dict`) - optional RFC 2425 parameters Overrides: VCardField.__init__

### rfc2426(self) | source code
RFC2426-encode the field content. Returns: `str` the field in the RFC 2426 format. Overrides: VCardField.rfc2426

### as_xml(self, parent) | source code
Create vcard-tmp XML representation of the field. Parameters: `parent` (`libxml2.xmlNode`) - parent node for the element Returns: `libxml2.xmlNode` xml node with the field data.